==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebComponentDateValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDateValueChangedEventArgsDescription } from "./WebComponentDateValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentDateValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentDateValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentDateValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentDateValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentDateValueChangedEventArgsDescriptionMetadata.c(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebComponentDateValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentDateValueChangedEventArgs");
            a.item("Detail", "Date");
        }
        static d(a) {
            WebComponentDateValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("WebComponentDateValueChangedEventArgs", () => new WebComponentDateValueChangedEventArgsDescription());
            a.z("WebComponentDateValueChangedEventArgs", WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentDateValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentDateValueChangedEventArgsDescriptionMetadata, 'WebComponentDateValueChangedEventArgsDescriptionMetadata');
    WebComponentDateValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDateValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebComponentDateValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentDateValueChangedEventArgsDescription } from "./WebComponentDateValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentDateValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentDateValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentDateValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentDateValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentDateValueChangedEventArgsDescriptionMetadata.c(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebComponentDateValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentDateValueChangedEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Detail", "Date");
        }
        static d(a) {
            WebComponentDateValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("WebComponentDateValueChangedEventArgs", () => new WebComponentDateValueChangedEventArgsDescription());
            a.ab("WebComponentDateValueChangedEventArgs", WebComponentDateValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentDateValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebComponentDateValueChangedEventArgsDescriptionMetadata, 'WebComponentDateValueChangedEventArgsDescriptionMetadata');
    WebComponentDateValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentDateValueChangedEventArgsDescriptionMetadata;
})();
